/**
 * InfoCommandList - a List of Solaris information commands
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import java.util.*;

public class InfoCommandList extends Vector {

  //a backing hash so we can look up commands by description
  private Hashtable infoHash;

  /**
   * Construct a List of available commands.
   * Note that it's actually a Vector.
   */
  public InfoCommandList() {
    infoHash = new Hashtable();
    //add all the possible commands here
    addCommand("Disk Use", "/usr/sbin/df", "-kl");
    addCommand("Hostid", "/usr/bin/hostid");
    addCommand("Isainfo", "/usr/bin/isainfo", "-v");
    addCommand("Kernel Modules", "/usr/sbin/modinfo");
    addCommand("Patches", "/usr/bin/showrev", "-p");
    addCommand("Prtconf", "/usr/sbin/prtconf");
    addCommand("Prtdiag", "/usr/sbin/prtdiag");
    addCommand("Prtfru", "/usr/sbin/prtfru");
    addCommand("Prtpicl", "/usr/sbin/prtpicl");
    addCommand("Psrinfo", "/usr/sbin/psrinfo", "-v");
    addCommand("Routing", "/sbin/routeadm");
    addCommand("Rpcinfo", "/usr/bin/rpcinfo", "-s");
    addCommand("Shares", "/usr/sbin/share");
    addCommand("Swap", "/usr/sbin/swap", "-l");
    addCommand("Uname", "/usr/bin/uname", "-a");
    addCommand("Uptime", "/usr/bin/uptime");
    addCommand("Zone List", "/usr/sbin/zoneadm", "list -icv");
  }

  private void addCommand(String text, String cmd) {
    addCommand(text, cmd, (String) null);
  }

  private void addCommand(String text, String cmd, String args) {
    addCommand(new InfoCommand(text, cmd, args));
  }

  private void addCommand(InfoCommand infocmd) {
    if (infocmd.exists()) {
      if (!infoHash.containsKey(infocmd.toString())) {
	infoHash.put(infocmd.toString(), infocmd);
	add(infocmd);
      }
    }
  }

  public InfoCommand getCmd(String text) {
    return (InfoCommand) infoHash.get(text);
  }

  public String infoTable(String pkg) {
    return infoTable((InfoCommand) infoHash.get(pkg));
  }

  public String infoTable(InfoCommand infocmd) {
    StringBuffer sb = new StringBuffer();
    sb.append("Output from <b>").append(infocmd.getFullCmd());
    sb.append("</b>\n<hr>\n");
    sb.append("<pre>");
    sb.append(infocmd.getOutput());
    sb.append("</pre>");
    return sb.toString();
  }
}
