/**
 * SolView - shows Solaris information
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import uk.co.petertribble.jingle.*;

public class SolView implements ActionListener {

  static String[] savedArgs;

  InstalledClusterPanel icp;

  JMenuItem exitItem;
  JMenuItem cloneItem;
  JMenuItem closeItem;
  JMenuItem infoItem;
  JMenuItem depItem;
  JMenuItem helpItem;
  JMenuItem licenseItem;
  JFrame jf;

  public SolView(String[] args) {
    jf = new JFrame("Solview");
    jf.addWindowListener(new winExit());

    JTabbedPane jtp = new JTabbedPane();
    jf.getContentPane().add(jtp,BorderLayout.CENTER);

    JMenuBar jm = new JMenuBar();

    //jtp.add("Packages", new PkgPanel());
    icp = new InstalledClusterPanel();
    jtp.add("Installed Software", icp);
    jtp.add("Services", new SmfPanel());
    jtp.add("Information", new InfoPanel());

    JMenu jme = new JMenu("File");
    jme.setMnemonic(KeyEvent.VK_F);
    cloneItem = new JMenuItem("New Browser", KeyEvent.VK_B);
    cloneItem.addActionListener(this);
    jme.add(cloneItem);
    closeItem = new JMenuItem("Close Window", KeyEvent.VK_W);
    closeItem.addActionListener(this);
    jme.add(closeItem);
    exitItem = new JMenuItem("Exit", KeyEvent.VK_X);
    exitItem.addActionListener(this);
    jme.add(exitItem);

    JingleMultiFrame.register(jf, closeItem);

    jm.add(jme);
    jm.add(new SolToolsMenu());

    // Menu to create dependency trees
    JMenu jmd = new JMenu("Dependencies");
    depItem = new JMenuItem("Check for Installed system");
    depItem.addActionListener(this);
    jmd.add(depItem);
    jm.add(jmd);

    JMenu jmh = new JMenu("Help");
    jmh.setMnemonic(KeyEvent.VK_H);
    helpItem = new JMenuItem("About solview", KeyEvent.VK_A);
    helpItem.addActionListener(this);
    jmh.add(helpItem);
    licenseItem = new JMenuItem("License", KeyEvent.VK_L);
    licenseItem.addActionListener(this);
    jmh.add(licenseItem);

    jm.add(jmh);
    jf.setJMenuBar(jm);

    for (int i = 0; i < args.length; i++ ) {
      final ClusterPanel cp = new ClusterPanel(args[i]);
      jtp.add("Distribution", cp);
      JMenuItem distDepItem = new JMenuItem("Check for "+args[i]);
      jmd.add(distDepItem);
      distDepItem.addActionListener(new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	  cp.createRevDependencies();
	}
      });
    }

    jf.setSize(640,480);
    jf.setVisible(true);
  }

  class winExit extends WindowAdapter {
     public void windowClosing(WindowEvent we)
     {
        System.exit(0);
     }
  }

  public void actionPerformed(ActionEvent e) {
    if (e.getSource() == cloneItem) {
      new SolView(savedArgs);
    }
    if (e.getSource() == closeItem) {
      JingleMultiFrame.unregister(jf);
    }
    if (e.getSource() == exitItem) {
      System.exit(0);
    }
    if (e.getSource() == depItem) {
      icp.createRevDependencies();
    }
    if (e.getSource() == helpItem) {
      new JingleInfoFrame(this.getClass().getClassLoader(),
			"help/index.html", "text/html");
    }
    if (e.getSource() == licenseItem) {
      new JingleInfoFrame(this.getClass().getClassLoader(),
			"help/CDDL.txt", "text/plain");
    }
  }

  public static void main (String args[]) {
    savedArgs = args;
    new SolView(args);
  }

}
